@@ -5,7 +5,7 @@ use warnings;
 use Email::Valid;
 use Time::Piece;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use base 'Exporter';
 our @EXPORT= qw/NOT_BLANK INT ASCII STRING DECIMAL EMAIL DATETIME DATE TIME TINYINT URL LENGTH BETWEEN DIGIT_LENGTH/;
@@ -52,6 +52,7 @@ sub EMAIL{
 sub DATETIME{
     my $s = shift;
     return 1 unless $s;
+    return 0 unless $s =~ m!^\d{4}(?:-|/)\d{2}(?:-|/)\d{2} \d{2}(?::|-)\d{2}(?::|-)\d{2}$!;
     eval{
         Time::Piece->strptime($s , "%Y-%m-%d %H:%M:%S");
     };
@@ -122,6 +123,8 @@ sub LENGTH{
 sub DIGIT_LENGTH{
     my ($s , $integer , $decimal) = @_;
     my ($integer_value , $decimal_value) = $s =~ m/(\d+)\.(\d+)/;
+    $integer_value ||= "";
+    $decimal_value ||= "";
 
     if(length($integer_value) <= $integer && length($decimal_value) <= $decimal){
         return 1;
@@ -154,7 +157,7 @@ FormValidator::Simple::Struct::Regex - Plugin for FormValidator::Simple::Struct
 
 =head1 VERSION
 
-This document describes FormValidator::Simple::Struct::Regex version 0.15.
+This document describes FormValidator::Simple::Struct::Regex version 0.16.
 
 =head1 SYNOPSIS
 
@@ -197,7 +200,7 @@ This module provides some validate methods based on regex
  
  # not allow multi bytes characters
  ng $v->check(
-    ["あ" , "漢字"],
+    [Non-ASCII character],
     ["ASCII"]);
 
 =head3 DECIMAL
